/* The purpose of this function is to return the index of the sidebar accordion which should be opened by default.
   This function uses param "key" (see header.dox) to determine which accordion is currently being processed. */
function autoExpand(key)
{
    /* This is simply defaulting to opening the API accordion if it's an API page */
    if (location.href.includes("api_ref"))
    {
        if (key == "top_level")
            return 2;
        else 
            return false;
    }
    
    /* Otherwise, it finds the special tag in each file and opens the accordion that way. */
    var autoExpands = $( "#autoExpand" ).find("span");
    
    for (var i = 0; i < autoExpands.length; i++)
    {
        var pos = autoExpands[i].innerText.search(":");
        
        if (pos == -1) 
            continue; // something unexpected. ignore.
        
        var accordion = autoExpands[i].innerText.substring(0, pos);
        var expandedSection = autoExpands[i].innerText.substring(pos + 1, autoExpands[i].innerText.length);

        if (key == accordion)
            return parseInt(expandedSection, 10);
    }
    
    return false;
}


// Not all possible URLs have an entry in the sidebar, therefore nothing gets highlighted. 
// For example, the individual class pages don't have individual menu entries. So this 
// function provides a substitute so the code can highlight an appropriate entry in the 
// sidebar and the breadcrumbs will work.
function findSubstituteLeafAnchor()
{
    // this array means any URL which contains an orphans.url value will be correlated with the url in orphans.home
    var orphans = [ { url: "/api_ref/3dgs/", home: "build/api_ref/3dgs/api_ref_index.html" },
                    { url: "/api_ref/mvo/", home: "build/api_ref/mvo/classes.html" },
                    { url: "/api_ref/3dgs_stream/", home: "build/api_ref/3dgs_stream/classes.html" },
                    { url: "/api_ref/base_stream/", home: "build/api_ref/base_stream/classes.html" },
                    { url: "/api_ref/mvo/", home: "build/api_ref/hio/api_ref_index.html" },
                    { url: "/api_ref/ooc/", home: "build/api_ref/ooc/classes.html" },
                    { url: "/opcodes/", home: "build/general/hsf/HSF_architecture.html" }
    ];
    
    for (var i = 0; i < orphans.length; i++)
    {
        if (location.href.includes(orphans[i].url))
        {
            var anchors = $( "#accordion_panel" ).find("a");
            
            for (var j = 0; j < anchors.length; j++)
            {
                pos = anchors[j].href.search("build");
                
                if (pos == -1) continue; // something unexpected. ignore.
                
                currentUrl = anchors[j].href.substring(pos);
                
                if (currentUrl.includes(orphans[i].home))
                {
                    return anchors[j];
                }
            }
        }
    }
    
    // this should never happen, but returning empty so we don't ever run into a null issue
    return "";
}


// on some pages, breadcrumbs are not appropriate. test before generating.
function shouldGenerateBreadcrumbs()
{
    var urls = [ "main-landing", "api_ref", "/general/" ];
    
    for (var i = 0; i < urls.length; i++)
    {
        if (location.href.includes(urls[i]))
            return false;
    }
    
    return true;
}